nltk.sem package
================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.sem.boxer
   nltk.sem.chat80
   nltk.sem.cooper_storage
   nltk.sem.drt
   nltk.sem.drt_glue_demo
   nltk.sem.evaluate
   nltk.sem.glue
   nltk.sem.hole
   nltk.sem.lfg
   nltk.sem.linearlogic
   nltk.sem.logic
   nltk.sem.relextract
   nltk.sem.skolemize
   nltk.sem.util

Module contents
---------------

.. automodule:: nltk.sem
   :members:
   :undoc-members:
   :show-inheritance:
